@@ -10,8 +10,8 @@ urlpatterns = patterns('',
     url(r'^admin/', include(admin.site.urls), name='admin'),
     url(r'^upload/?$', views.upload, name='upload'),
     url(r'^search/?$', views.search, name='search'),
-    url(r'^lib/(.*)$', views.library, name='library'),
-    url(r'^lib/(.*)/(.*)$', views.library, name='keyword'),
+    url(r'^lib/([^/]*)$', views.library, name='library'),
+    url(r'^lib/(.*)/(.*)$', views.library, name='version'),
     url(r'^$', views.index, name='root')
 )
 
